Slot: recommended - LinkML Model

# Slot: recommended

true means that the slot should be present in the loaded definition, but this is not required

URI: linkml:recommended

## Domain and Range

SlotDefinition → 0..1 Boolean

## Parents

## Children

## Used by

- SlotDefinition

## Other properties

Comments: |  | This is to be used where not all data is expected to conform to having a required field
|  | If a slot is recommended, and it is not populated, applications must not treat this as an error. Applications may use this to inform the user of missing data
See also: |  | https://github.com/linkml/linkml/issues/177